#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""Tests for `fab_support` package."""


import unittest

from fab_support import pelican


class TestFab_support(unittest.TestCase):
    """Tests for `fab_support` package."""

    def setUp(self):
        """Set up test fixtures, if any."""

    def tearDown(self):
        """Tear down test fixtures, if any."""

    def test_000_something(self):
        """Test something."""
